#' Tools for the continuous convolution trick in nonparametric estimation
#'
#' Implements the uniform scaled beta distribution [dusb()], a generic function
#' for continuous convolution [cont_conv()], and the continuous convolution
#' kernel density estimator [cckde()].
#'
#' @name cctools-package
#' @aliases cctools
#' @useDynLib cctools, .registration = TRUE
#'
#' @author Thomas Nagler
#'
#' @references
#' Nagler, T. (2017). *A generic approach to nonparametric function
#' estimation with mixed data.* [arXiv:1704.07457](https://arxiv.org/pdf/1704.07457)
#'
#' @keywords package
#'
"_PACKAGE"
